"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const definition_1 = require("../definition");
const command_1 = (0, tslib_1.__importDefault)(require("../command"));
const flags = (0, tslib_1.__importStar)(require("../flags"));
const args_1 = require("../args");
const cli_1 = require("../cli");
class Deploy extends command_1.default {
    /*
      Oclif doesn't type parsed args & flags correctly and especially
      required-ness which is not known by the compiler, thus the use of
      the non-null assertion '!' in this command.
      See https://github.com/oclif/oclif/issues/301 for details
    */
    async run() {
        const { args, flags } = this.parse(Deploy);
        const api = await definition_1.API.load(args.FILE);
        const [definition, references] = api.extractDefinition();
        const action = flags['dry-run'] ? 'validate' : 'deploy';
        /* eslint-disable-next-line @typescript-eslint/no-non-null-assertion */
        const [documentation, token] = [flags.doc, flags.token];
        this.d(`${args.FILE} looks like an ${api.specName} spec version ${api.version}`);
        cli_1.cli.action.start(`* Let's ${action} a new documentation version on Bump`);
        const request = {
            documentation,
            hub: flags.hub,
            documentation_name: flags['doc-name'],
            auto_create_documentation: flags['auto-create'] && !flags['dry-run'],
            definition,
            references,
            branch_name: flags.branch,
        };
        const response = flags['dry-run']
            ? await this.bump.postValidation(request, token)
            : await this.bump.postVersion(request, token);
        cli_1.cli.action.stop();
        switch (response.status) {
            case 200:
                cli_1.cli.styledSuccess('Definition is valid');
                break;
            case 201:
                const version = response.data
                    ? response.data
                    : { id: '', doc_public_url: 'https://bump.sh' };
                cli_1.cli.styledSuccess(`Your new documentation version will soon be ready at ${version.doc_public_url}`);
                break;
            case 204:
                this.warn('Your documentation has not changed');
                break;
        }
        return;
    }
}
exports.default = Deploy;
Deploy.description = 'Create a new version of your documentation from the given file or URL.';
Deploy.examples = [
    `Deploy a new version of an existing documentation

$ bump deploy FILE --doc <your_doc_id_or_slug> --token <your_doc_token>
* Let's deploy a new documentation version on Bump... done
* Your new documentation version will soon be ready
`,
    `Deploy a new version of an existing documentation attached to a hub

$ bump deploy FILE --doc <doc_slug> --hub <your_hub_id_or_slug> --token <your_doc_token>
* Let's deploy a new documentation version on Bump... done
* Your new documentation version will soon be ready
`,
    `Validate a new documentation version before deploying it

$ bump deploy FILE --dry-run --doc <doc_slug> --token <your_doc_token>
* Let's validate a new documentation version on Bump... done
* Definition is valid
`,
];
Deploy.flags = {
    help: flags.help({ char: 'h' }),
    doc: flags.doc(),
    'doc-name': flags.docName(),
    hub: flags.hub(),
    branch: flags.branch(),
    token: flags.token(),
    'auto-create': flags.autoCreate(),
    'dry-run': flags.dryRun(),
};
Deploy.args = [args_1.fileArg];
